@@ -1,6 +1,6 @@
 (* camlp5r *)
-(* $Id: pa_o.ml,v 6.35 2011-03-24 15:31:50 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2011 *)
+(* $Id: pa_o.ml,v 6.38 2012-01-09 14:22:21 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_extend.cmo";
 #load "q_MLast.cmo";
@@ -771,6 +771,9 @@ EXTEND
       | s = V INT_L -> <:patt< $_int64:s$ >>
       | s = V INT_n -> <:patt< $_nativeint:s$ >>
       | "-"; s = INT -> <:patt< $int:"-" ^ s$ >>
+      | "-"; s = INT_l -> <:patt< $int32:"-" ^ s$ >>
+      | "-"; s = INT_L -> <:patt< $int64:"-" ^ s$ >>
+      | "-"; s = INT_n -> <:patt< $nativeint:"-" ^ s$ >>
       | "-"; s = FLOAT -> <:patt< $flo:"-" ^ s$ >>
       | s = V FLOAT -> <:patt< $_flo:s$ >>
       | s = V STRING -> <:patt< $_str:s$ >>
@@ -812,7 +815,8 @@ EXTEND
       | le = lbl_patt -> [le] ] ]
   ;
   lbl_patt:
-    [ [ i = patt_label_ident; "="; p = patt -> (i, p) ] ]
+    [ [ i = patt_label_ident; "="; p = patt -> (i, p)
+      | "_" -> (<:patt< _ >>, <:patt< _ >>) ] ]
   ;
   patt_label_ident:
     [ LEFTA
