@@ -1,6 +1,6 @@
 (* camlp5r pa_macro.cmo *)
-(* $Id: versdep.ml,v 6.14 2011-03-15 12:12:40 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2010 *)
+(* $Id: versdep.ml,v 6.19 2012-01-09 14:22:21 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2012 *)
 
 open Parsetree;
 open Longident;
@@ -46,6 +46,24 @@ value ocaml_location (fname, lnum, bolp, lnuml, bolpl, bp, ep) =
   END
 ;
 
+value ocaml_id_or_li_of_string_list loc sl =
+  IFDEF OCAML_VERSION < OCAML_3_13_0 THEN
+    match List.rev sl with
+    [ [s] -> Some s
+    | _ -> None ]
+  ELSE
+    let mkli s =
+      loop (fun s -> Lident s) where rec loop f =
+        fun
+        [ [i :: il] -> loop (fun s -> Ldot (f i) s) il
+        | [] -> f s ]
+    in
+    match List.rev sl with
+    [ [] -> None
+    | [s :: sl] -> Some (mkli s (List.rev sl)) ]
+  END
+;
+
 value list_map_check f l =
   loop [] l where rec loop rev_l =
     fun
@@ -89,7 +107,13 @@ value ocaml_type_declaration params cl tk pf tm loc variance =
           Right
             {ptype_params = params; ptype_cstrs = cl; ptype_kind = tk;
              ptype_manifest = tm; ptype_loc = loc; ptype_variance = variance}
+        ELSIFDEF OCAML_VERSION < OCAML_3_13_0 THEN
+          Right
+            {ptype_params = params; ptype_cstrs = cl; ptype_kind = tk;
+             ptype_private = pf; ptype_manifest = tm; ptype_loc = loc;
+             ptype_variance = variance}
         ELSE
+          let params = List.map (fun os -> Some os) params in
           Right
             {ptype_params = params; ptype_cstrs = cl; ptype_kind = tk;
              ptype_private = pf; ptype_manifest = tm; ptype_loc = loc;
@@ -157,19 +181,31 @@ value ocaml_ptype_variant ctl priv =
           let priv = if priv then Private else Public in
           Some (Ptype_variant ctl priv)
         END
-      ELSE
+      ELSIFDEF OCAML_VERSION < OCAML_3_11 THEN
         let ctl =
           List.map
             (fun (c, tl, rto, loc) ->
                if rto <> None then raise Exit else (c, tl, loc))
             ctl
         in
-        IFDEF OCAML_VERSION < OCAML_3_11 THEN
           let priv = if priv then Private else Public in
           Some (Ptype_variant ctl priv)
-        ELSE
+      ELSIFDEF OCAML_VERSION < OCAML_3_13_0 THEN
+        let ctl =
+          List.map
+            (fun (c, tl, rto, loc) ->
+               if rto <> None then raise Exit else (c, tl, loc))
+            ctl
+        in
+          Some (Ptype_variant ctl)
+      ELSE
+        let ctl =
+          List.map
+            (fun (c, tl, rto, loc) ->
+               if rto <> None then raise Exit else (c, tl, None, loc))
+            ctl
+        in
           Some (Ptype_variant ctl)
-        END
       END
     with
     [ Exit -> None ]
@@ -318,7 +354,8 @@ value ocaml_pexp_pack =
   ELSIFDEF OCAML_VERSION < OCAML_3_13_0 THEN
     Some (Left (fun me pt -> Pexp_pack me pt))
   ELSE
-    Some (Right (fun me -> Pexp_pack me, fun pt -> Ptyp_package pt))
+    (Some (Right (fun me -> Pexp_pack me, fun pt -> Ptyp_package pt)) :
+     option (choice ('a -> 'b -> 'c) 'd))
   END
 ;
 
@@ -368,8 +405,9 @@ value ocaml_ppat_lazy =
   ELSE None END
 ;
 
-value ocaml_ppat_record lpl =
-  IFDEF OCAML_VERSION >= OCAML_3_12 THEN Ppat_record lpl Closed
+value ocaml_ppat_record lpl closed =
+  IFDEF OCAML_VERSION >= OCAML_3_12 THEN
+    Ppat_record lpl (if closed then Closed else Open)
   ELSE Ppat_record lpl END
 ;
 
@@ -446,7 +484,8 @@ value ocaml_pmod_unpack =
   ELSIFDEF OCAML_VERSION < OCAML_3_13_0 THEN
     Some (Left (fun e pt -> Pmod_unpack e pt))
   ELSE
-    Some (Right (fun e -> Pmod_unpack e, fun pt -> Ptyp_package pt))
+    (Some (Right (fun e -> Pmod_unpack e, fun pt -> Ptyp_package pt)) :
+     option (choice ('a -> 'b -> 'c) 'd))
   END
 ;
 
