@@ -1,13 +1,13 @@
 (* camlp5r *)
-(* $Id: pcaml.ml,v 6.21 2011-05-21 13:22:19 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2011 *)
+(* $Id: pcaml.ml,v 6.28 2012-03-01 07:35:07 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_macro.cmo";
 #load "pa_extend.cmo";
 
 open Printf;
 
-value version = "6.02.3";
+value version = "6.04";
 value syntax_name = ref "";
 
 value gram =
@@ -484,7 +484,7 @@ add_option "-mode"
       [ "S" -> strict_mode.val := True
       | "T" -> strict_mode.val := False
       | _ -> failwith "bad mode; use option -help for details" ]))
-  "<mode> Set strict (S) or transitional (T) mode.";
+  "<mode> Set strict (S) or transitional (T) mode (bootstrapping only).";
 
 add_option "-pmode"
   (Arg.Unit
