@@ -1,6 +1,6 @@
 (* camlp5r *)
-(* $Id: pa_r.ml,v 6.35 2011-02-17 10:14:09 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2010 *)
+(* $Id: pa_r.ml,v 6.38 2012-01-09 14:22:22 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_extend.cmo";
 #load "q_MLast.cmo";
@@ -530,7 +530,8 @@ EXTEND
       [ p1 = SELF; "."; p2 = SELF -> <:patt< $p1$ . $p2$ >> ]
     | "simple" RIGHTA
       [ i = V UIDENT -> <:patt< $_uid:i$ >>
-      | i = V LIDENT -> <:patt< $_lid:i$ >> ] ]
+      | i = V LIDENT -> <:patt< $_lid:i$ >>
+      | "_" -> <:patt< _ >> ] ]
   ;
   ipatt:
     [ [ "{"; lpl = V (LIST1 label_ipatt SEP ";"); "}" ->
