@@ -1,6 +1,6 @@
 (* camlp5r *)
-(* $Id: q_MLast.ml,v 6.33 2011-03-15 13:49:12 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2011 *)
+(* $Id: q_MLast.ml,v 6.35 2012-01-09 14:22:22 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_extend.cmo";
 #load "pa_extend_m.cmo";
@@ -903,7 +903,8 @@ EXTEND
       [ p1 = SELF; "."; p2 = SELF -> Qast.Node "PaAcc" [Qast.Loc; p1; p2] ]
     | "simple" RIGHTA
       [ i = SV UIDENT -> Qast.Node "PaUid" [Qast.Loc; i]
-      | i = SV LIDENT -> Qast.Node "PaLid" [Qast.Loc; i] ] ]
+      | i = SV LIDENT -> Qast.Node "PaLid" [Qast.Loc; i]
+      | "_" -> Qast.Node "PaAny" [Qast.Loc] ] ]
   ;
   ipatt:
     [ [ "{"; lpl = SV (LIST1 label_ipatt SEP ";"); "}" ->
